==> pydra2app-0.18.0.tar.gz: pydra2app-0.18.0/README.md <==
# Pydra2App

[![Tests](https://github.com/ArcanaFramework/pydra2app/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/ArcanaFramework/pydra2app/actions/workflows/ci-cd.yml)
[![Codecov](https://codecov.io/gh/ArcanaFramework/pydra2app/branch/main/graph/badge.svg?token=UIS0OGPST7)](https://codecov.io/gh/ArcanaFramework/pydra2app)
[![Python versions](https://img.shields.io/pypi/pyversions/pydra2app.svg)](https://pypi.python.org/pypi/pydra2app/)
[![Latest Version](https://img.shields.io/pypi/v/pydra2app.svg)](https://pypi.python.org/pypi/pydra2app/)
[![Docs](https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat)](https://arcanaframework.github.io/pydra2app)

<img src="./docs/source/_static/images/logo_small.png" alt="Logo Small" style="float: right;">

[Pydra2App](http://arcanaframework.github.io/pydra2app) is a tool for quickly turning
[Pydra](http://pydra.readthedocs.io) tasks into containerised applications
(e.g. [BIDS](http://bids.neuroimaging.io/) Apps or [XNAT](http://xnat.org) pipelines)

## Documentation

Detailed documentation on Pydra2App can be found at [https://arcanaframework.github.io/pydra2app](https://arcanaframework.github.io/pydra2app)

## Installation

Pydra2App can be installed for Python 3 using *pip*:

```bash
python3 -m pip install pydra2app
```

This will enable you run basic apps against generic directory trees, however, if you want
to build specific apps you will also need to install the appropriate extension package, e.g.

```bash
python3 -m pip install pydra2app-xnat
```

## License

This work is licensed under a
[Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License](http://creativecommons.org/licenses/by-nc-sa/4.0/)

[![Creative Commons License: Attribution-NonCommercial-ShareAlike 4.0 International](https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png)](http://creativecommons.org/licenses/by-nc-sa/4.0/)

## Acknowledgements

The authors acknowledge the facilities and scientific and technical assistance of the National Imaging Facility, a National Collaborative Research Infrastructure Strategy (NCRIS) capability.

==> pydra2app-0.18.1.tar.gz: pydra2app-0.18.1/README.md <==
# Pydra2App

[![Tests](https://github.com/ArcanaFramework/pydra2app/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/ArcanaFramework/pydra2app/actions/workflows/ci-cd.yml)
[![Codecov](https://codecov.io/gh/ArcanaFramework/pydra2app/branch/main/graph/badge.svg?token=UIS0OGPST7)](https://codecov.io/gh/ArcanaFramework/pydra2app)
[![Python versions](https://img.shields.io/pypi/pyversions/pydra2app.svg)](https://pypi.python.org/pypi/pydra2app/)
[![Latest Version](https://img.shields.io/pypi/v/pydra2app.svg)](https://pypi.python.org/pypi/pydra2app/)
[![Docs](https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat)](https://arcanaframework.github.io/pydra2app)

<img src="./docs/source/_static/images/logo_small.png" alt="Logo Small" style="float: right;">

[Pydra2App](http://arcanaframework.github.io/pydra2app) is a tool for turning
[Pydra](http://pydra.readthedocs.io) tasks into containerised applications
(e.g. [BIDS](http://bids.neuroimaging.io/) Apps or [XNAT](http://xnat.org) pipelines)

## Documentation

Detailed documentation on Pydra2App can be found at [https://arcanaframework.github.io/pydra2app](https://arcanaframework.github.io/pydra2app)

## Installation

Pydra2App can be installed for Python 3 using *pip*:

```bash
python3 -m pip install pydra2app
```

This will enable you run basic apps against generic directory trees, however, if you want
to build specific apps you will also need to install the appropriate extension package, e.g.

```bash
python3 -m pip install pydra2app-xnat
```

## License

This work is licensed under a
[Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License](http://creativecommons.org/licenses/by-nc-sa/4.0/)

[![Creative Commons License: Attribution-NonCommercial-ShareAlike 4.0 International](https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png)](http://creativecommons.org/licenses/by-nc-sa/4.0/)

## Acknowledgements

The authors acknowledge the facilities and scientific and technical assistance of the National Imaging Facility, a National Collaborative Research Infrastructure Strategy (NCRIS) capability.
